#
# spec file for package seahorse-nautilus
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           seahorse-nautilus
Version:        3.11.92
Release:        lp150.2.2
Summary:        Extension for nautilus which allows encryption and decryption of files
License:        GPL-2.0-or-later
Group:          Productivity/Security
URL:            http://live.gnome.org/Seahorse
Source:         http://download.gnome.org/sources/seahorse-nautilus/3.11/%{name}-%{version}.tar.xz
BuildRequires:  gpgme-devel
BuildRequires:  intltool >= 0.35.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cryptui-0.0) >= 3.9.90
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gcr-3) > 3.4.0
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.10.0
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0
BuildRequires:  pkgconfig(libnautilus-extension) >= 2.12.0
%glib2_gsettings_schema_requires

%description
Seahorse nautilus is an extension for nautilus which allows encryption
and decryption of OpenPGP files using GnuPG.

%package -n nautilus-extension-seahorse
Summary:        Extension for nautilus which allows encryption and decryption of files
Group:          Productivity/Security
Recommends:     %{name}-lang
Supplements:    packageand(seahorse:nautilus)
# For people looking for the upstream name, and to make lang package
# installable
Provides:       %{name} = %{version}

%description -n nautilus-extension-seahorse
Seahorse nautilus is an extension for nautilus which allows encryption
and decryption of OpenPGP files using GnuPG.

%lang_package

%prep
%setup -q
sed -i "s:1.2 1.4 2.0:1.2 1.4 2.0 2.1 2.2:" configure

%build
%configure
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file seahorse-pgp-signature
%suse_update_desktop_file seahorse-pgp-keys
%suse_update_desktop_file seahorse-pgp-encrypted
%find_lang %{name}

%post -n nautilus-extension-seahorse
%desktop_database_post
%glib2_gsettings_schema_post

%postun -n nautilus-extension-seahorse
%desktop_database_postun
%glib2_gsettings_schema_postun

%files -n nautilus-extension-seahorse
%license COPYING
%doc AUTHORS ChangeLog NEWS README THANKS
%{_bindir}/seahorse-tool
%{_libdir}/nautilus/extensions-3.0/libnautilus-seahorse.so
%{_datadir}/applications/seahorse-pgp*.desktop
%{_datadir}/%{name}/
%{_datadir}/GConf/gsettings/org.gnome.seahorse.nautilus.convert
%{_datadir}/glib-2.0/schemas/org.gnome.seahorse.nautilus.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.seahorse.nautilus.window.gschema.xml
%{_mandir}/man1/seahorse-tool.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Aug 29 2017 dimstar@opensuse.org
- Add 2.2 to the list of accepted GPG versions.
* Tue Feb  9 2016 egeorget@openmailbox.org
- Move seahorse-nautilus-lang recommends from main package to
  nautilus-extension-seahorse: there is no binary main package
  produce (%%name is also provided by nautilus-extension-seahorse).
* Tue Dec 16 2014 dimstar@opensuse.org
- Inject version 2.1 as acceptable gpg version into configure:
  GPG 2.1 is verified to be compatible and supported.
* Mon Mar 17 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Warn when signatures are valid but untrusted (bgo#708640).
  + License update (FSF address).
  + Documentation fixes.
  + Updated translations.
* Thu Oct 17 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + no changes since previous release.
* Mon Aug 26 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Add correct flag for reaping the progress child (bgo#697895).
  + Add support for symmetric encryption in seahorse-tool
    (bgo#325803).
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + No changes since previous release.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Updated translations.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Updated translatons.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Fix the GSettings schema.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Stable release: no changes since previous release.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Updated translations.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Updated translations
- Changes from version 3.5.4:
  + Update for newer Gtk and Glib
  + Use Gcr library for prompting of passwords
  + Migrate from GConf to GSettings
  + Fix several crashers
  + Updated translations.
- Add pkgconfig(gcr-3.0) BuildRequires: new dependency.
- Drop pkgconfig(gconf-2.0) BuildRequires: no longer needed after
  the port to GSettings.
- Add glib2_gsettings_schema_* macro handling.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + No changes.
* Mon Oct 31 2011 dimstar@opensuse.org
- Initial unstable release, split out from seahorse-plugins
  (version 3.3.1).
